.. image:: http://vmlaker.github.io/coils/logo.png
  :alt: Coils Logo
  :target: http://vmlaker.github.io/coils
.. image:: https://img.shields.io/pypi/v/coils.svg
  :alt: Pypi version
  :target: https://pypi.python.org/pypi/coils
.. image:: https://api.travis-ci.org/vmlaker/coils.png?branch=master
  :alt: Build Result Image
  :target: https://travis-ci.org/vmlaker/coils
.. image:: https://img.shields.io/pypi/l/coils.svg
  :alt: Pypi License
  :target: https://pypi.python.org/pypi/coils

Coils
=====

Read `the docs <http://vmlaker.github.io/coils>`_.
